@@ -558,7 +558,7 @@ const char *ScriptChecks::chkRemove(Line *line, ScriptImage *img)
         if(getMember(line))  
                 return "member not used for this command";  
 
-        if(!useKeywords(line, "=token=field=token=offset"))
+        if(!useKeywords(line, "=field=token=offset"))
                 return "invalid keyword used for this command";
 
         return chkFirstVar(line, img);
