@@ -91,7 +91,12 @@ void ScriptImage::addRegistration(Line *line)
 {
 	line->next = registration;
 	line->scr.name = current;
-	registration = line->next;
+	registration = line;
+}
+
+ScriptRegistry *ScriptImage::getRegistry(void)
+{
+	return (ScriptRegistry *)alloc(sizeof(ScriptRegistry));
 }
 
 void ScriptImage::addRoute(Line *line, unsigned pri)
